Code coverage report for js/widgets/IntegerInputWidget.tsx

# All files / js/widgets IntegerInputWidget.tsx

37.5% Statements 3/8
0% Branches 0/4
0% Functions 0/3
37.5% Lines 3/8

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    281x

    1x
    1x

     import React from "react";
    import { WidgetProps } from "./types";
    import { trans } from "../i18n";
    import InputWidgetBase from "./InputWidgetBase";

    function postprocessInteger(value: string) {
      return value.trim();
    }

    function validateInteger(value: string) {
      if (value && !value.match(/^-?\d+$/)) {
        return trans("ERROR_INVALID_NUMBER");
      }
      return null;
    }

    export function IntegerInputWidget(props: WidgetProps) {
      return (
        <InputWidgetBase
          inputType="text"
          inputAddon="0"
          postprocessValue={postprocessInteger}
          validate={validateInteger}
          {...props}
        />
      );
    }